@@ -134,9 +134,11 @@ impl PafRecord {
             let caps = pattern.captures(token).unwrap();
             let tag = &caps[1];
             let value = &caps[3];
-            if tag == "cs" {
-                cigar = cs_to_cigar(value)?;
-            } else if tag == "cg" {
+            // TODO fix cs string parsing when both cigar and cs are there. breaks on real files
+            //if tag == "cs" {
+            //    cigar = cs_to_cigar(value)?;
+            //} else
+            if tag == "cg" && cigar.len() == 0 {
                 cigar = cigar_from_str(value)?;
             } else {
                 tags.push('\t');
@@ -459,9 +461,7 @@ pub fn paf_swap_query_and_target(paf: &PafRecord) -> PafRecord {
     flipped.q_en = paf.t_en;
 
     // flip the index
-    let temp = flipped.qpos_aln;
-    flipped.qpos_aln = flipped.tpos_aln;
-    flipped.tpos_aln = temp;
+    std::mem::swap(&mut flipped.qpos_aln, &mut flipped.tpos_aln);
 
     if paf.strand == '-' {
         flipped.qpos_aln.reverse();
